AppConfig class

Constructors

AppConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

buttonStyles AppButtonStyles
getter/setter pair
colors AppColors
getter/setter pair
getter/setter pair
textStyles AppTextStyles
getter/setter pair

Static Methods

setButtonStyles(AppButtonStyles newButtonStyles) → void
setColors(AppColors newColors) → void
setDropdownMenuTheme(AppDropdownMenuTheme newDropdownMenuTheme) → void
setTextStyles(AppTextStyles newTextStyles) → void