AppColors class
Constructors
- AppColors({required Color primaryLight, required Color primaryDark, required Color secondary, required Color backgroundLight, required Color backgroundDark, required Color surfaceLight, required Color surfaceDark, required Color onPrimaryLight, required Color onPrimaryDark, required Color unselectedItemLight, required Color unselectedItemDark})
-
const
Properties
- appBarDarkBg → Color
-
no setter
- appBarDarkFg → Color
-
no setter
- appBarLightBg → Color
-
no setter
- appBarLightFg → Color
-
no setter
- backgroundDark → Color
-
final
- backgroundLight → Color
-
final
- darkColorScheme → ColorScheme
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputBorderDark → Color
-
no setter
- inputBorderLight → Color
-
no setter
- inputFillDark → Color
-
no setter
- inputFillLight → Color
-
no setter
- lightColorScheme → ColorScheme
-
no setter
- onPrimaryDark → Color
-
final
- onPrimaryLight → Color
-
final
- primaryDark → Color
-
final
- primaryLight → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaffoldDarkBg → Color
-
no setter
- scaffoldLightBg → Color
-
no setter
- secondary → Color
-
final
- selectedBottomItemDark → Color
-
no setter
- selectedBottomItemLight → Color
-
no setter
- surfaceDark → Color
-
final
- surfaceDarkBg → Color
-
no setter
- surfaceLight → Color
-
final
- surfaceLightBg → Color
-
no setter
- unselectedItemDark → Color
-
final
- unselectedItemLight → Color
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited