AppDropdownMenuTheme class

Constructors

AppDropdownMenuTheme({required DropdownMenuThemeData lightTheme, required DropdownMenuThemeData darkTheme})
const

Properties

darkTheme DropdownMenuThemeData
final
hashCode int
The hash code for this object.
no setterinherited
lightTheme DropdownMenuThemeData
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromColors() AppDropdownMenuTheme